# @HEADER
# ************************************************************************
#
#            TriBITS: Tribal Build, Integrate, and Test System
#                    Copyright 2013 Sandia Corporation
#
#
# Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
# the U.S. Government retains certain rights in this software.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
# 1. Redistributions of source code must retain the above copyright
# notice, this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright
# notice, this list of conditions and the following disclaimer in the
# documentation and/or other materials provided with the distribution.
#
# 3. Neither the name of the Corporation nor the names of the
# contributors may be used to endorse or promote products derived from
# this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY SANDIA CORPORATION "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL SANDIA CORPORATION OR THE
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# ************************************************************************
# @HEADER

##############################################################################
#
# CMake variable for use by Trilinos/STKSearchUtil clients.
#
# Do not edit: This file was generated automatically by CMake.
#
##############################################################################


# Include guard
IF (STKSearchUtil_CONFIG_INCLUDED)
  RETURN()
ENDIF()
SET(STKSearchUtil_CONFIG_INCLUDED TRUE)

# Make sure CMAKE_CURRENT_LIST_DIR is usable
IF (NOT DEFINED CMAKE_CURRENT_LIST_DIR)
  GET_FILENAME_COMPONENT(_THIS_SCRIPT_PATH ${CMAKE_CURRENT_LIST_FILE} PATH)
  SET(CMAKE_CURRENT_LIST_DIR ${_THIS_SCRIPT_PATH})
ENDIF()


## ---------------------------------------------------------------------------
## Compilers used by Trilinos/STKSearchUtil build
## ---------------------------------------------------------------------------

SET(STKSearchUtil_CXX_COMPILER "/usr/bin/mpicxx")

SET(STKSearchUtil_C_COMPILER "/usr/bin/mpicc")

SET(STKSearchUtil_FORTRAN_COMPILER "/usr/bin/mpif90")


## ---------------------------------------------------------------------------
## Compiler flags used by Trilinos/STKSearchUtil build
## ---------------------------------------------------------------------------

## Set compiler flags, including those determined by build type
SET(STKSearchUtil_CXX_FLAGS "  -march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt -std=c++11 ")

SET(STKSearchUtil_C_FLAGS "  -march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt ")

SET(STKSearchUtil_FORTRAN_FLAGS " ")

## Extra link flags (e.g., specification of fortran libraries)
SET(STKSearchUtil_EXTRA_LD_FLAGS "")

## This is the command-line entry used for setting rpaths. In a build
## with static libraries it will be empty.
SET(STKSearchUtil_SHARED_LIB_RPATH_COMMAND "-Wl,-rpath,/usr/lib")
SET(STKSearchUtil_BUILD_SHARED_LIBS "ON")

SET(STKSearchUtil_LINKER /usr/bin/ld)
SET(STKSearchUtil_AR /usr/bin/ar)

## ---------------------------------------------------------------------------
## Set library specifications and paths
## ---------------------------------------------------------------------------

## List of package include dirs
SET(STKSearchUtil_INCLUDE_DIRS "${CMAKE_CURRENT_LIST_DIR}/../../../include")

## List of package library paths
SET(STKSearchUtil_LIBRARY_DIRS "${CMAKE_CURRENT_LIST_DIR}/../../../lib")

## List of package libraries
SET(STKSearchUtil_LIBRARIES "stk_search_util_base;stk_search;stk_mesh_base;stk_topology;stk_util_use_cases;stk_util_registry;stk_util_diag;stk_util_env;stk_util_parallel;stk_util_util;aprepro_lib;shards;kokkosalgorithms;kokkoscontainers;kokkoscore;tpi")

## Specification of directories for TPL headers
SET(STKSearchUtil_TPL_INCLUDE_DIRS "/usr/include;/usr/include")

## Specification of directories for TPL libraries
SET(STKSearchUtil_TPL_LIBRARY_DIRS "")

## List of required TPLs
SET(STKSearchUtil_TPL_LIBRARIES "/usr/lib/libdl.so;/usr/lib/libboost_program_options.so;/usr/lib/libboost_system.so;/usr/lib/libblas.so")

## ---------------------------------------------------------------------------
## MPI specific variables
##   These variables are provided to make it easier to get the mpi libraries
##   and includes on systems that do not use the mpi wrappers for compiling
## ---------------------------------------------------------------------------

SET(STKSearchUtil_MPI_LIBRARIES "")
SET(STKSearchUtil_MPI_LIBRARY_DIRS "")
SET(STKSearchUtil_MPI_INCLUDE_DIRS "")
SET(STKSearchUtil_MPI_EXEC "/usr/bin/mpiexec")
SET(STKSearchUtil_MPI_EXEC_MAX_NUMPROCS "4")
SET(STKSearchUtil_MPI_EXEC_NUMPROCS_FLAG "-np")

## ---------------------------------------------------------------------------
## Set useful general variables
## ---------------------------------------------------------------------------

## The packages enabled for this project
SET(STKSearchUtil_PACKAGE_LIST "STKSearchUtil;STKSearch;STKMesh;STKTopology;STKUtil;SEACASAprepro_lib;Shards;Kokkos;KokkosAlgorithms;KokkosContainers;KokkosCore;ThreadPool")

## The TPLs enabled for this project
SET(STKSearchUtil_TPL_LIST "DLlib;BoostLib;Boost;BLAS;MPI;Pthread")


# Include configuration of dependent packages
INCLUDE("${CMAKE_CURRENT_LIST_DIR}/../STKSearch/STKSearchConfig.cmake")
INCLUDE("${CMAKE_CURRENT_LIST_DIR}/../STKMesh/STKMeshConfig.cmake")
INCLUDE("${CMAKE_CURRENT_LIST_DIR}/../STKTopology/STKTopologyConfig.cmake")
INCLUDE("${CMAKE_CURRENT_LIST_DIR}/../STKUtil/STKUtilConfig.cmake")
INCLUDE("${CMAKE_CURRENT_LIST_DIR}/../SEACASAprepro_lib/SEACASAprepro_libConfig.cmake")
INCLUDE("${CMAKE_CURRENT_LIST_DIR}/../Shards/ShardsConfig.cmake")
INCLUDE("${CMAKE_CURRENT_LIST_DIR}/../Kokkos/KokkosConfig.cmake")
INCLUDE("${CMAKE_CURRENT_LIST_DIR}/../KokkosAlgorithms/KokkosAlgorithmsConfig.cmake")
INCLUDE("${CMAKE_CURRENT_LIST_DIR}/../KokkosContainers/KokkosContainersConfig.cmake")
INCLUDE("${CMAKE_CURRENT_LIST_DIR}/../KokkosCore/KokkosCoreConfig.cmake")
INCLUDE("${CMAKE_CURRENT_LIST_DIR}/../ThreadPool/ThreadPoolConfig.cmake")

# Import STKSearchUtil targets
INCLUDE("${CMAKE_CURRENT_LIST_DIR}/STKSearchUtilTargets.cmake")
